/*
 * SoundClip.java - a cached sound clip.
 *
 * 09-May-2006, ver 0.50
 *
 * COPYRIGHT: Copyright (c) 2006 Brendan Gregg.
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software Foundation,
 *  Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 *  (http://www.gnu.org/copyleft/gpl.html)
 *
 * 09-May-2006  Brendan Gregg   Created this.
 */

import java.io.*;
import java.net.URL;
import java.lang.Class;
import javax.sound.sampled.*;

/**
 * Cache a small sound effect in RAM, for quick playback.
 * This currently only accepts .wav files.
 */
public class SoundClip {

    // variables
    private static final int BUFSIZE = 65536;   // max clip size
    public byte[] sample;
    public int bytes;
    public DataLine.Info info;
    public AudioFormat format;

    // constructor
    public SoundClip() {
        bytes = 0;
    }

    /**
     * Create a SoundClip by loading the given sound file.
     */
    public SoundClip(String fileName) {
        URL url = getClass().getResource(fileName);
        try {
            AudioInputStream audio = AudioSystem.getAudioInputStream(url);
            format = audio.getFormat();
            info = new DataLine.Info(SourceDataLine.class, format);
            sample = new byte[BUFSIZE];
            bytes = audio.read(sample, 0, sample.length);
        } catch (UnsupportedAudioFileException e) {
            System.out.println("ERROR (file type): " + e.toString());
            System.exit(-1);
        } catch (IOException e) {
            System.out.println("ERROR (I/O): " + e.toString());
            System.exit(-1);
        }
    }
}
